==> haskell-descriptive-0.9.4-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-descriptive/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: descriptive
version: 0.9.4
id: descriptive-0.9.4-ad2f4cfc97addd061c093602616293e9
key: descr_LPz1xwcqIcI0wv4leo83Rq
license: BSD3
copyright: 2015 Chris Done
maintainer: chrisdone@gmail.com
stability: Experimental
homepage: https://github.com/chrisdone/descriptive
synopsis: Self-describing consumers/parsers; forms, cmd-line args, JSON, etc.
description:
    Self-describing consumers/parsers. See the README.md for more information. It is currently EXPERIMENTAL.
category: Parsing
author: Chris Done
exposed: True
exposed-modules:
    Descriptive Descriptive.Char Descriptive.Form Descriptive.Formlet
    Descriptive.Options Descriptive.JSON
hidden-modules: Descriptive.Internal
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/descriptive-0.9.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/descriptive-0.9.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/descriptive-0.9.4
hs-libraries: HSdescriptive-0.9.4-LPz1xwcqIcI0wv4leo83Rq
depends:
    aeson-0.10.0.0-d37842f030fec47bc6e0ba2aef0f6571
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bifunctors-5.2.1-ac140f775ddaa28955bf641042d171b3
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    scientific-0.3.4.4-3faa9d36abc45b55aed128d427a02fce
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-descriptive/html/descriptive.haddock
haddock-html: /usr/share/doc/haskell-descriptive/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-descriptive-0.9.4-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-descriptive/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: descriptive
version: 0.9.4
id: descriptive-0.9.4-a5d8b9583a1589652bfd0d3b2a4beca1
key: descr_HtIbBO1ognBHqvv0f1DIZW
license: BSD3
copyright: 2015 Chris Done
maintainer: chrisdone@gmail.com
stability: Experimental
homepage: https://github.com/chrisdone/descriptive
synopsis: Self-describing consumers/parsers; forms, cmd-line args, JSON, etc.
description:
    Self-describing consumers/parsers. See the README.md for more information. It is currently EXPERIMENTAL.
category: Parsing
author: Chris Done
exposed: True
exposed-modules:
    Descriptive Descriptive.Char Descriptive.Form Descriptive.Formlet
    Descriptive.Options Descriptive.JSON
hidden-modules: Descriptive.Internal
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/descriptive-0.9.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/descriptive-0.9.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/descriptive-0.9.4
hs-libraries: HSdescriptive-0.9.4-HtIbBO1ognBHqvv0f1DIZW
depends:
    aeson-0.10.0.0-d37842f030fec47bc6e0ba2aef0f6571
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bifunctors-5.2.1-773112418cac918e191cb2ad7385e9ee
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    scientific-0.3.4.4-3faa9d36abc45b55aed128d427a02fce
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-descriptive/html/descriptive.haddock
haddock-html: /usr/share/doc/haskell-descriptive/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
